@@ -1,7 +1,7 @@
 package App::ZodiacUtils;
 
-our $DATE = '2015-11-21'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-11-28'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -34,7 +34,7 @@ $SPEC{zodiac_of} = {
     ],
 };
 sub zodiac_of {
-    require DateTime::Event::Zodiac;
+    require Zodiac::Tiny;
     my %args = @_;
 
     #my $dates = $args{dates};
@@ -42,7 +42,7 @@ sub zodiac_of {
 
     my $res = [];
     for my $date (@$dates) {
-        push @$res, DateTime::Event::Zodiac::zodiac_date_name($date);
+        push @$res, Zodiac::Tiny::zodiac_of($date);
     }
     $res = $res->[0] if @$res == 1;
     $res;
@@ -104,7 +104,7 @@ App::ZodiacUtils - CLI utilities related to zodiac
 
 =head1 VERSION
 
-This document describes version 0.02 of App::ZodiacUtils (from Perl distribution App-ZodiacUtils), released on 2015-11-21.
+This document describes version 0.03 of App::ZodiacUtils (from Perl distribution App-ZodiacUtils), released on 2015-11-28.
 
 =head1 DESCRIPTION
 
